/*
  Copyright (C) 2002-2004 SKYRIX Software AG

  This file is part of OpenGroupware.org.

  OGo is free software; you can redistribute it and/or modify it under
  the terms of the GNU Lesser General Public License as published by the
  Free Software Foundation; either version 2, or (at your option) any
  later version.

  OGo is distributed in the hope that it will be useful, but WITHOUT ANY
  WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
  License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with OGo; see the file COPYING.  If not, write to the
  Free Software Foundation, 59 Temple Place - Suite 330, Boston, MA
  02111-1307, USA.
*/

#ifndef __SoObjects_SoActionInvocation_H__
#define __SoObjects_SoActionInvocation_H__

#import <Foundation/NSObject.h>

/*
  An invocation object for WODirectAction based SoClass methods.
  
  If the invocation is bound, the action is instantiated and initialized,
  if it is called, the "actionName" is called and the result is returned or
  if no "actionName" is set, the default action is called.
*/

@class NSString, NSDictionary, NSMutableString;

@interface SoActionInvocation : NSObject
{
  NSString     *actionClassName;
  NSString     *actionName;
  
  /* for bound invocations */
  id           methodObject;
  id           object;
  
  NSDictionary *argumentSpecifications;
}

- (id)initWithActionClassName:(NSString *)_cn;
- (id)initWithActionClassName:(NSString *)_cn actionName:(NSString *)_action;

/* accessors */

- (NSString *)actionClassName;
- (NSString *)actionName;

- (void)setArgumentSpecifications:(NSDictionary *)_specs;
- (NSDictionary *)argumentSpecifications;

/* bindings */

- (BOOL)isBound;
- (id)bindToObject:(id)_object inContext:(id)_ctx;

/* description */

- (void)appendAttributesToDescription:(NSMutableString *)_ms;

@end

#endif /* __SoObjects_SoActionInvocation_H__ */
